Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5944)

Unified Diff: chrome/browser/views/toolbar_view.h

Issue 4524002: First cut of the about:conflicts page, listing all DLLs loaded in the Chrome ... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/views/toolbar_view.h
===================================================================
--- chrome/browser/views/toolbar_view.h (revision 65039)
+++ chrome/browser/views/toolbar_view.h (working copy)
@@ -142,6 +142,9 @@
// Returns true if we should show the upgrade recommended dot.
bool IsUpgradeRecommended();
+ // Returns true if we should show the warning for incompatible software.
+ bool ShouldShowIncompatibilityWarning();
+
// Returns the number of pixels above the location bar in non-normal display.
int PopupTopSpacing() const;
@@ -158,12 +161,12 @@
return display_mode_ == DISPLAYMODE_NORMAL;
}
// Starts the recurring timer that periodically asks the upgrade notifier
// to pulsate.
- void ShowUpgradeReminder();
+ void ShowNotificationDot();
- // Show the reminder, tempting the user to upgrade by pulsating.
- void PulsateUpgradeNotifier();
+ // Show the reminder, tempting the user to take a look.
+ void PulsateNotificationDot();
// Gets a canvas with the icon for the app menu. It will possibly contain
// an overlaid badge if an update is recommended.
@@ -210,12 +213,12 @@
// Vector of listeners to receive callbacks when the menu opens.
std::vector<views::MenuListener*> menu_listeners_;
- // The animation that makes the update reminder pulse.
- scoped_ptr<SlideAnimation> update_reminder_animation_;
+ // The animation that makes the notification dot pulse.
+ scoped_ptr<SlideAnimation> notification_dot_animation_;
// We periodically restart the animation after it has been showed
// once, to create a pulsating effect.
- base::RepeatingTimer<ToolbarView> upgrade_reminder_pulse_timer_;
+ base::RepeatingTimer<ToolbarView> notification_dot_pulse_timer_;
// Used to post tasks to switch to the next/previous menu.
ScopedRunnableMethodFactory<ToolbarView> method_factory_;
@@ -158,12 +161,12 @@
return display_mode_ == DISPLAYMODE_NORMAL;
}
- // Starts the recurring timer that periodically asks the upgrade notifier
+ // Starts the recurring timer that periodically asks the notification dot
// to pulsate.

Powered by Google App Engine
This is Rietveld 408576698